==> openshift-model-hive-5.12.1-sources.jar: io/fabric8/openshift/api/model/hive/v1/HiveConfigBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class HiveConfigBuilder extends io.fabric8.openshift.api.model.hive.v1.HiveConfigFluentImpl<io.fabric8.openshift.api.model.hive.v1.HiveConfigBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.hive.v1.HiveConfig,io.fabric8.openshift.api.model.hive.v1.HiveConfigBuilder>{
  public HiveConfigBuilder() {
    this(false);
  }
  public HiveConfigBuilder(java.lang.Boolean validationEnabled) {
    this(new HiveConfig(), validationEnabled);
  }
  public HiveConfigBuilder(io.fabric8.openshift.api.model.hive.v1.HiveConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public HiveConfigBuilder(io.fabric8.openshift.api.model.hive.v1.HiveConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new HiveConfig(), validationEnabled);
  }
  public HiveConfigBuilder(io.fabric8.openshift.api.model.hive.v1.HiveConfigFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.HiveConfig instance) {
    this(fluent, instance, false);
  }
  public HiveConfigBuilder(io.fabric8.openshift.api.model.hive.v1.HiveConfigFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.HiveConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public HiveConfigBuilder(io.fabric8.openshift.api.model.hive.v1.HiveConfig instance) {
    this(instance,false);
  }
  public HiveConfigBuilder(io.fabric8.openshift.api.model.hive.v1.HiveConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.hive.v1.HiveConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.hive.v1.HiveConfig build() {
    HiveConfig buildable = new HiveConfig(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HiveConfigBuilder that = (HiveConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-hive-6.5.1-sources.jar: io/fabric8/openshift/api/model/hive/v1/HiveConfigBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class HiveConfigBuilder extends HiveConfigFluentImpl<HiveConfigBuilder> implements VisitableBuilder<HiveConfig,HiveConfigBuilder>{
  public HiveConfigBuilder() {
    this(false);
  }
  public HiveConfigBuilder(Boolean validationEnabled) {
    this(new HiveConfig(), validationEnabled);
  }
  public HiveConfigBuilder(HiveConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public HiveConfigBuilder(HiveConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new HiveConfig(), validationEnabled);
  }
  public HiveConfigBuilder(HiveConfigFluent<?> fluent,HiveConfig instance) {
    this(fluent, instance, false);
  }
  public HiveConfigBuilder(HiveConfigFluent<?> fluent,HiveConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public HiveConfigBuilder(HiveConfig instance) {
    this(instance,false);
  }
  public HiveConfigBuilder(HiveConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  HiveConfigFluent<?> fluent;
  Boolean validationEnabled;
  public HiveConfig build() {
    HiveConfig buildable = new HiveConfig(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
